@@ -38,14 +38,15 @@
 #include <unictype.h>
 
 static bool
-_isBidi (const uint32_t *label, size_t llen)
+_isBidi (const uint32_t * label, size_t llen)
 {
-  for (; (ssize_t) llen > 0; llen--) {
-    int bc = uc_bidi_category (*label++);
+  for (; (ssize_t) llen > 0; llen--)
+    {
+      int bc = uc_bidi_category (*label++);
 
-    if (bc == UC_BIDI_R || bc == UC_BIDI_AL || bc == UC_BIDI_AN)
-      return 1;
-  }
+      if (bc == UC_BIDI_R || bc == UC_BIDI_AL || bc == UC_BIDI_AN)
+	return 1;
+    }
 
   return 0;
 }
@@ -61,22 +62,29 @@ _idn2_bidi (const uint32_t * label, size_t llen)
     return IDN2_OK;
 
   // 2.1
-  switch ((bc = uc_bidi_category (*label))) {
+  switch ((bc = uc_bidi_category (*label)))
+    {
     case UC_BIDI_L:
       // check 2.5 & 2.6
-      for (size_t it = 1; it < llen; it++) {
-	bc = uc_bidi_category(label[it]);
+      for (size_t it = 1; it < llen; it++)
+	{
+	  bc = uc_bidi_category (label[it]);
 
-	if (bc == UC_BIDI_L || bc == UC_BIDI_EN || bc == UC_BIDI_NSM) {
-	  endok = 1;
-	} else {
-	  if (bc != UC_BIDI_ES && bc != UC_BIDI_CS && bc != UC_BIDI_ET && bc != UC_BIDI_ON && bc != UC_BIDI_BN) {
-	    /* printf("LTR label contains invalid code point\n"); */
-	    return IDN2_BIDI;
-	  }
-	  endok = 0;
+	  if (bc == UC_BIDI_L || bc == UC_BIDI_EN || bc == UC_BIDI_NSM)
+	    {
+	      endok = 1;
+	    }
+	  else
+	    {
+	      if (bc != UC_BIDI_ES && bc != UC_BIDI_CS && bc != UC_BIDI_ET
+		  && bc != UC_BIDI_ON && bc != UC_BIDI_BN)
+		{
+		  /* printf("LTR label contains invalid code point\n"); */
+		  return IDN2_BIDI;
+		}
+	      endok = 0;
+	    }
 	}
-      }
       /* printf("LTR label ends with invalid code point\n"); */
       return endok ? IDN2_OK : IDN2_BIDI;
 
@@ -84,25 +92,32 @@ _idn2_bidi (const uint32_t * label, size_t llen)
     case UC_BIDI_AL:
       // check 2.2, 2.3, 2.4
       /* printf("Label[0]=%04X: %s\n", label[0], uc_bidi_category_name(bc)); */
-      for (size_t it = 1; it < llen; it++) {
-	bc = uc_bidi_category(label[it]);
+      for (size_t it = 1; it < llen; it++)
+	{
+	  bc = uc_bidi_category (label[it]);
 
-	/* printf("Label[%d]=%04X: %s\n", (int) it, label[it], uc_bidi_category_name(bc)); */
-	if (bc == UC_BIDI_R || bc == UC_BIDI_AL || bc == UC_BIDI_EN || bc == UC_BIDI_AN || bc == UC_BIDI_NSM) {
-	  endok = 1;
-	} else {
-	  if (bc != UC_BIDI_ES && bc != UC_BIDI_CS && bc != UC_BIDI_ET && bc != UC_BIDI_ON && bc != UC_BIDI_BN) {
-	    /* printf("RTL label contains invalid code point\n"); */
-	    return IDN2_BIDI;
-	  }
-	  endok = 0;
+	  /* printf("Label[%d]=%04X: %s\n", (int) it, label[it], uc_bidi_category_name(bc)); */
+	  if (bc == UC_BIDI_R || bc == UC_BIDI_AL || bc == UC_BIDI_EN
+	      || bc == UC_BIDI_AN || bc == UC_BIDI_NSM)
+	    {
+	      endok = 1;
+	    }
+	  else
+	    {
+	      if (bc != UC_BIDI_ES && bc != UC_BIDI_CS && bc != UC_BIDI_ET
+		  && bc != UC_BIDI_ON && bc != UC_BIDI_BN)
+		{
+		  /* printf("RTL label contains invalid code point\n"); */
+		  return IDN2_BIDI;
+		}
+	      endok = 0;
+	    }
 	}
-      }
       /* printf("RTL label ends with invalid code point\n"); */
       return endok ? IDN2_OK : IDN2_BIDI;
 
     default:
       /* printf("Label begins with invalid BIDI class %s\n", uc_bidi_category_name(bc)); */
       return IDN2_BIDI;
-  }
+    }
 }
