@@ -58,13 +58,12 @@ enum
 };
 
 extern int
-	_idn2_u8_to_u32_nfc (const uint8_t * src, size_t srclen,
-		uint32_t ** out, size_t * outlen, int nfc);
+_idn2_u8_to_u32_nfc (const uint8_t * src, size_t srclen,
+		     uint32_t ** out, size_t *outlen, int nfc);
 
 extern G_GNUC_IDN2_ATTRIBUTE_PURE bool
-	_idn2_ascii_p (const uint8_t * src, size_t srclen);
+_idn2_ascii_p (const uint8_t * src, size_t srclen);
 
-extern int
-	_idn2_label_test (int what, const uint32_t * label, size_t llen);
+extern int _idn2_label_test (int what, const uint32_t * label, size_t llen);
 
 #endif /* LIBIDN2_IDNA_H */
