@@ -31,18 +31,18 @@
 
 #include "idn2.h"
 
-#include <errno.h>      /* errno */
-#include <stdlib.h>     /* malloc, free */
+#include <errno.h>		/* errno */
+#include <stdlib.h>		/* malloc, free */
 
 #include "punycode.h"
 
 #include <unitypes.h>
-#include <uniconv.h>    /* u8_strconv_from_locale */
-#include <uninorm.h>    /* u32_normalize */
-#include <unistr.h>     /* u8_to_u32 */
+#include <uniconv.h>		/* u8_strconv_from_locale */
+#include <uninorm.h>		/* u32_normalize */
+#include <unistr.h>		/* u8_to_u32 */
 
-#include "idna.h"       /* _idn2_label_test */
-#include "tr46map.h"    /* definition for tr46map.c */
+#include "idna.h"		/* _idn2_label_test */
+#include "tr46map.h"		/* definition for tr46map.c */
 
 #ifdef HAVE_LIBUNISTRING
 /* copied from gnulib */
@@ -67,6 +67,7 @@ c_tolower (int c)
       return c;
     }
 }
+
 static int
 c_strncasecmp (const char *s1, const char *s2, size_t n)
 {
@@ -83,7 +84,7 @@ c_strncasecmp (const char *s1, const char *s2, size_t n)
       c2 = c_tolower (*p2);
 
       if (--n == 0 || c1 == '\0')
-        break;
+	break;
 
       ++p1;
       ++p2;
@@ -102,25 +103,28 @@ c_strncasecmp (const char *s1, const char *s2, size_t n)
 #include <c-strcase.h>
 #endif
 
-static int set_default_flags(int *flags)
+static int
+set_default_flags (int *flags)
 {
   if (((*flags) & IDN2_TRANSITIONAL) && ((*flags) & IDN2_NONTRANSITIONAL))
     return IDN2_INVALID_FLAGS;
 
-  if (((*flags) & (IDN2_TRANSITIONAL|IDN2_NONTRANSITIONAL)) && ((*flags) & IDN2_NO_TR46))
+  if (((*flags) & (IDN2_TRANSITIONAL | IDN2_NONTRANSITIONAL))
+      && ((*flags) & IDN2_NO_TR46))
     return IDN2_INVALID_FLAGS;
 
-  if (((*flags) & IDN2_ALABEL_ROUNDTRIP) && ((*flags) & IDN2_NO_ALABEL_ROUNDTRIP))
+  if (((*flags) & IDN2_ALABEL_ROUNDTRIP)
+      && ((*flags) & IDN2_NO_ALABEL_ROUNDTRIP))
     return IDN2_INVALID_FLAGS;
 
-  if (!((*flags) & (IDN2_NO_TR46|IDN2_TRANSITIONAL)))
+  if (!((*flags) & (IDN2_NO_TR46 | IDN2_TRANSITIONAL)))
     *flags |= IDN2_NONTRANSITIONAL;
 
   return IDN2_OK;
 }
 
 static int
-label (const uint8_t * src, size_t srclen, uint8_t * dst, size_t * dstlen,
+label (const uint8_t * src, size_t srclen, uint8_t * dst, size_t *dstlen,
        int flags)
 {
   size_t plen;
@@ -132,42 +136,51 @@ label (const uint8_t * src, size_t srclen, uint8_t * dst, size_t * dstlen,
   uint32_t label_u32[IDN2_LABEL_MAX_LENGTH];
   size_t label32_len = IDN2_LABEL_MAX_LENGTH;
 
-  if (_idn2_ascii_p (src, srclen)) {
-    if (!(flags & IDN2_NO_ALABEL_ROUNDTRIP) && srclen >= 4 && memcmp (src, "xn--", 4) == 0) {
-      /*
-	 If the input to this procedure appears to be an A-label
-	 (i.e., it starts in "xn--", interpreted
-	 case-insensitively), the lookup application MAY attempt to
-	 convert it to a U-label, first ensuring that the A-label is
-	 entirely in lowercase (converting it to lowercase if
-	 necessary), and apply the tests of Section 5.4 and the
-	 conversion of Section 5.5 to that form. */
-      rc = _idn2_punycode_decode_internal (srclen - 4, (char *) src + 4, &label32_len, label_u32);
-      if (rc)
-	return rc;
+  if (_idn2_ascii_p (src, srclen))
+    {
+      if (!(flags & IDN2_NO_ALABEL_ROUNDTRIP) && srclen >= 4
+	  && memcmp (src, "xn--", 4) == 0)
+	{
+	  /*
+	     If the input to this procedure appears to be an A-label
+	     (i.e., it starts in "xn--", interpreted
+	     case-insensitively), the lookup application MAY attempt to
+	     convert it to a U-label, first ensuring that the A-label is
+	     entirely in lowercase (converting it to lowercase if
+	     necessary), and apply the tests of Section 5.4 and the
+	     conversion of Section 5.5 to that form. */
+	  rc =
+	    _idn2_punycode_decode_internal (srclen - 4, (char *) src + 4,
+					    &label32_len, label_u32);
+	  if (rc)
+	    return rc;
 
-      check_roundtrip = 1;
-      src_org = src;
-      srclen_org = srclen;
+	  check_roundtrip = 1;
+	  src_org = src;
+	  srclen_org = srclen;
 
-      srclen = IDN2_LABEL_MAX_LENGTH;
-      src = src_allocated = u32_to_u8 (label_u32, label32_len, NULL, &srclen);
-      if (!src) {
-	if (errno == ENOMEM)
-	  return IDN2_MALLOC;
-	return IDN2_ENCODING_ERROR;
-      }
-    } else {
-      if (srclen > IDN2_LABEL_MAX_LENGTH)
-	return IDN2_TOO_BIG_LABEL;
-      if (srclen > *dstlen)
-	return IDN2_TOO_BIG_DOMAIN;
+	  srclen = IDN2_LABEL_MAX_LENGTH;
+	  src = src_allocated =
+	    u32_to_u8 (label_u32, label32_len, NULL, &srclen);
+	  if (!src)
+	    {
+	      if (errno == ENOMEM)
+		return IDN2_MALLOC;
+	      return IDN2_ENCODING_ERROR;
+	    }
+	}
+      else
+	{
+	  if (srclen > IDN2_LABEL_MAX_LENGTH)
+	    return IDN2_TOO_BIG_LABEL;
+	  if (srclen > *dstlen)
+	    return IDN2_TOO_BIG_DOMAIN;
 
-      memcpy (dst, src, srclen);
-      *dstlen = srclen;
-      return IDN2_OK;
+	  memcpy (dst, src, srclen);
+	  *dstlen = srclen;
+	  return IDN2_OK;
+	}
     }
-  }
 
   rc = _idn2_u8_to_u32_nfc (src, srclen, &p, &plen, flags & IDN2_NFC_INPUT);
   if (rc != IDN2_OK)
@@ -175,17 +188,19 @@ label (const uint8_t * src, size_t srclen, uint8_t * dst, size_t * dstlen,
 
   if (!(flags & IDN2_TRANSITIONAL))
     {
-      rc = _idn2_label_test(
-	TEST_NFC |
-	TEST_2HYPHEN |
-	TEST_LEADING_COMBINING |
-	TEST_DISALLOWED |
-	TEST_CONTEXTJ_RULE |
-	TEST_CONTEXTO_WITH_RULE |
-	TEST_UNASSIGNED | TEST_BIDI |
-	((flags & IDN2_NONTRANSITIONAL) ? TEST_NONTRANSITIONAL : 0) |
-	((flags & IDN2_USE_STD3_ASCII_RULES) ? 0 : TEST_ALLOW_STD3_DISALLOWED),
-	p, plen);
+      rc = _idn2_label_test (TEST_NFC |
+			     TEST_2HYPHEN |
+			     TEST_LEADING_COMBINING |
+			     TEST_DISALLOWED |
+			     TEST_CONTEXTJ_RULE |
+			     TEST_CONTEXTO_WITH_RULE |
+			     TEST_UNASSIGNED | TEST_BIDI |
+			     ((flags & IDN2_NONTRANSITIONAL) ?
+			      TEST_NONTRANSITIONAL : 0) | ((flags &
+							    IDN2_USE_STD3_ASCII_RULES)
+							   ? 0 :
+							   TEST_ALLOW_STD3_DISALLOWED),
+			     p, plen);
 
       if (rc != IDN2_OK)
 	goto out;
@@ -206,26 +221,29 @@ label (const uint8_t * src, size_t srclen, uint8_t * dst, size_t * dstlen,
 
   if (check_roundtrip)
     {
-      if (srclen_org != *dstlen || c_strncasecmp ((char *) src_org, (char *) dst, srclen_org))
-        {
+      if (srclen_org != *dstlen
+	  || c_strncasecmp ((char *) src_org, (char *) dst, srclen_org))
+	{
 	  rc = IDN2_ALABEL_ROUNDTRIP_FAILED;
 	  goto out;
-        }
+	}
     }
   else if (!(flags & IDN2_NO_ALABEL_ROUNDTRIP))
     {
-      rc = _idn2_punycode_decode_internal (*dstlen - 4, (char *) dst + 4, &label32_len, label_u32);
+      rc =
+	_idn2_punycode_decode_internal (*dstlen - 4, (char *) dst + 4,
+					&label32_len, label_u32);
       if (rc)
-        {
+	{
 	  rc = IDN2_ALABEL_ROUNDTRIP_FAILED;
 	  goto out;
-        }
+	}
 
       if (plen != label32_len || u32_cmp (p, label_u32, label32_len))
-        {
+	{
 	  rc = IDN2_ALABEL_ROUNDTRIP_FAILED;
 	  goto out;
-        }
+	}
     }
 
   rc = IDN2_OK;
@@ -255,7 +273,7 @@ _tr46 (const uint8_t * domain_u8, uint8_t ** out, int flags)
 
   /* convert UTF-8 to UTF-32 */
   if (!(domain_u32 =
-       u8_to_u32 (domain_u8, u8_strlen (domain_u8) + 1, NULL, &len)))
+	u8_to_u32 (domain_u8, u8_strlen (domain_u8) + 1, NULL, &len)))
     {
       if (errno == ENOMEM)
 	return IDN2_MALLOC;
@@ -300,7 +318,7 @@ _tr46 (const uint8_t * domain_u8, uint8_t ** out, int flags)
 	    len2++;
 	}
       else if (!(flags & IDN2_USE_STD3_ASCII_RULES))
-        {
+	{
 	  if (map_is (&map, TR46_FLG_DISALLOWED_STD3_VALID))
 	    {
 	      /* valid because UseSTD3ASCIIRules=false, see #TR46 5 */
@@ -311,7 +329,7 @@ _tr46 (const uint8_t * domain_u8, uint8_t ** out, int flags)
 	      /* mapped because UseSTD3ASCIIRules=false, see #TR46 5 */
 	      len2 += map.nmappings;
 	    }
-        }
+	}
     }
 
   /* Exit early if result is too long.
@@ -363,7 +381,7 @@ _tr46 (const uint8_t * domain_u8, uint8_t ** out, int flags)
 	    tmp[len2++] = c;
 	}
       else if (!(flags & IDN2_USE_STD3_ASCII_RULES))
-        {
+	{
 	  if (map_is (&map, TR46_FLG_DISALLOWED_STD3_VALID))
 	    {
 	      tmp[len2++] = c;
@@ -372,7 +390,7 @@ _tr46 (const uint8_t * domain_u8, uint8_t ** out, int flags)
 	    {
 	      len2 += get_map_data (tmp + len2, &map);
 	    }
-        }
+	}
     }
   free (domain_u32);
 
@@ -430,20 +448,19 @@ _tr46 (const uint8_t * domain_u8, uint8_t ** out, int flags)
 	  if (!(flags & IDN2_USE_STD3_ASCII_RULES))
 	    test_flags |= TEST_ALLOW_STD3_DISALLOWED;
 
-	  if ((rc =
-	       _idn2_label_test (test_flags, name_u32,
-				 name_len)))
+	  if ((rc = _idn2_label_test (test_flags, name_u32, name_len)))
 	    err = rc;
 	}
       else
 	{
-	  test_flags = transitional ? TR46_TRANSITIONAL_CHECK : TR46_NONTRANSITIONAL_CHECK;
+	  test_flags =
+	    transitional ? TR46_TRANSITIONAL_CHECK :
+	    TR46_NONTRANSITIONAL_CHECK;
 
 	  if (!(flags & IDN2_USE_STD3_ASCII_RULES))
 	    test_flags |= TEST_ALLOW_STD3_DISALLOWED;
 
-	  if ((rc =
-	       _idn2_label_test (test_flags, s, e - s)))
+	  if ((rc = _idn2_label_test (test_flags, s, e - s)))
 	    err = rc;
 	}
 
@@ -528,7 +545,7 @@ idn2_lookup_u8 (const uint8_t * src, uint8_t ** lookupname, int flags)
       return IDN2_OK;
     }
 
-  rc = set_default_flags(&flags);
+  rc = set_default_flags (&flags);
   if (rc != IDN2_OK)
     return rc;
 
@@ -554,17 +571,17 @@ idn2_lookup_u8 (const uint8_t * src, uint8_t ** lookupname, int flags)
 
       rc = label (src, labellen, tmp, &tmplen, flags);
       if (rc != IDN2_OK)
-      {
-	free (src_allocated);
-	return rc;
-      }
+	{
+	  free (src_allocated);
+	  return rc;
+	}
 
       if (lookupnamelen + tmplen
 	  > IDN2_DOMAIN_MAX_LENGTH - (tmplen == 0 && *end == '\0' ? 1 : 2))
-      {
-        free (src_allocated);
-	return IDN2_TOO_BIG_DOMAIN;
-      }
+	{
+	  free (src_allocated);
+	  return IDN2_TOO_BIG_DOMAIN;
+	}
 
       memcpy (_lookupname + lookupnamelen, tmp, tmplen);
       lookupnamelen += tmplen;
@@ -572,10 +589,10 @@ idn2_lookup_u8 (const uint8_t * src, uint8_t ** lookupname, int flags)
       if (*end == '.')
 	{
 	  if (lookupnamelen + 1 > IDN2_DOMAIN_MAX_LENGTH)
-	  {
-	    free (src_allocated);
-	    return IDN2_TOO_BIG_DOMAIN;
-	  }
+	    {
+	      free (src_allocated);
+	      return IDN2_TOO_BIG_DOMAIN;
+	    }
 
 	  _lookupname[lookupnamelen] = '.';
 	  lookupnamelen++;
@@ -639,7 +656,7 @@ idn2_lookup_u8 (const uint8_t * src, uint8_t ** lookupname, int flags)
  * Since: 0.1
  **/
 int
-idn2_lookup_ul (const char * src, char ** lookupname, int flags)
+idn2_lookup_ul (const char *src, char **lookupname, int flags)
 {
   uint8_t *utf8src = NULL;
   int rc;
@@ -701,9 +718,12 @@ idn2_lookup_ul (const char * src, char ** lookupname, int flags)
  * Return value: Returns %IDN2_OK on success, or error code.
  *
  * Since: 2.0.0
+ *
+ * Deprecated: 2.1.1: Use idn2_to_ascii_4i2().
  **/
 int
-idn2_to_ascii_4i (const uint32_t * input, size_t inlen, char * output, int flags)
+idn2_to_ascii_4i (const uint32_t * input, size_t inlen, char *output,
+		  int flags)
 {
   char *out;
   int rc;
@@ -717,22 +737,22 @@ idn2_to_ascii_4i (const uint32_t * input, size_t inlen, char * output, int flags
 
   rc = idn2_to_ascii_4i2 (input, inlen, &out, flags);
   if (rc == IDN2_OK)
-  {
-	  size_t len = strlen(out);
+    {
+      size_t len = strlen (out);
 
-	  if (len > 63)
-		  rc = IDN2_TOO_BIG_DOMAIN;
-	  else if (output)
-		  memcpy (output, out, len);
+      if (len > 63)
+	rc = IDN2_TOO_BIG_DOMAIN;
+      else if (output)
+	memcpy (output, out, len);
 
-	  free (out);
-  }
+      free (out);
+    }
 
   return rc;
 }
 
 /**
- * idn2_to_ascii_4i:
+ * idn2_to_ascii_4i2:
  * @input: zero terminated input Unicode (UCS-4) string.
  * @inlen: number of elements in @input.
  * @output: pointer to newly allocated zero-terminated output string.
@@ -766,7 +786,8 @@ idn2_to_ascii_4i (const uint32_t * input, size_t inlen, char * output, int flags
  * Since: 2.1.1
  **/
 int
-idn2_to_ascii_4i2 (const uint32_t * input, size_t inlen, char ** output, int flags)
+idn2_to_ascii_4i2 (const uint32_t * input, size_t inlen, char **output,
+		   int flags)
 {
   uint32_t *input_u32;
   uint8_t *input_u8, *output_u8;
@@ -780,7 +801,7 @@ idn2_to_ascii_4i2 (const uint32_t * input, size_t inlen, char ** output, int fla
       return IDN2_OK;
     }
 
-  input_u32 = (uint32_t *) malloc ((inlen + 1) * sizeof(uint32_t));
+  input_u32 = (uint32_t *) malloc ((inlen + 1) * sizeof (uint32_t));
   if (!input_u32)
     return IDN2_MALLOC;
 
@@ -803,7 +824,7 @@ idn2_to_ascii_4i2 (const uint32_t * input, size_t inlen, char ** output, int fla
     {
       if (output)
 	*output = (char *) output_u8;
-		else
+      else
 	free (output_u8);
     }
 
@@ -831,7 +852,7 @@ idn2_to_ascii_4i2 (const uint32_t * input, size_t inlen, char ** output, int fla
  * Since: 2.0.0
  **/
 int
-idn2_to_ascii_4z (const uint32_t * input, char ** output, int flags)
+idn2_to_ascii_4z (const uint32_t * input, char **output, int flags)
 {
   uint8_t *input_u8;
   size_t length;
@@ -844,7 +865,7 @@ idn2_to_ascii_4z (const uint32_t * input, char ** output, int flags)
       return IDN2_OK;
     }
 
-  input_u8 = u32_to_u8 (input, u32_strlen(input) + 1, NULL, &length);
+  input_u8 = u32_to_u8 (input, u32_strlen (input) + 1, NULL, &length);
   if (!input_u8)
     {
       if (errno == ENOMEM)
@@ -879,7 +900,7 @@ idn2_to_ascii_4z (const uint32_t * input, char ** output, int flags)
  * Since: 2.0.0
  **/
 int
-idn2_to_ascii_8z (const char * input, char ** output, int flags)
+idn2_to_ascii_8z (const char *input, char **output, int flags)
 {
   return idn2_lookup_u8 ((const uint8_t *) input, (uint8_t **) output, flags);
 }
@@ -906,7 +927,7 @@ idn2_to_ascii_8z (const char * input, char ** output, int flags)
  * Since: 2.0.0
  **/
 int
-idn2_to_ascii_lz (const char * input, char ** output, int flags)
+idn2_to_ascii_lz (const char *input, char **output, int flags)
 {
   return idn2_lookup_ul (input, output, flags);
 }
