@@ -61,7 +61,7 @@
 
 #include <config.h>
 
-#include "idn2.h" /* IDN2_OK, ... */
+#include "idn2.h"		/* IDN2_OK, ... */
 
 /* Re-definitions to avoid modifying code below too much. */
 #define punycode_uint uint32_t
@@ -81,8 +81,10 @@
 
 /*** Bootstring parameters for Punycode ***/
 
-enum { base = 36, tmin = 1, tmax = 26, skew = 38, damp = 700,
-       initial_bias = 72, initial_n = 0x80, delimiter = 0x2D };
+enum
+{ base = 36, tmin = 1, tmax = 26, skew = 38, damp = 700,
+  initial_bias = 72, initial_n = 0x80, delimiter = 0x2D
+};
 
 /* basic(cp) tests whether cp is a basic code point: */
 #define basic(cp) ((cp >= 'a' && cp <= 'z') || (cp >= '0' && cp <='9') || (cp >= 'A' && cp <='Z') || cp == '-' || cp == '_')
@@ -91,7 +93,8 @@ enum { base = 36, tmin = 1, tmax = 26, skew = 38, damp = 700,
 /* point (for use in representing integers) in the range 0 to */
 /* base-1, or base if cp does not represent a value.          */
 
-static unsigned decode_digit(int cp)
+static unsigned
+decode_digit (int cp)
 {
   if (cp >= 'a' && cp <= 'z')
     return cp - 'a';
@@ -111,11 +114,12 @@ static const punycode_uint maxint = -1;
 
 /*** Bias adaptation function ***/
 
-static punycode_uint adapt(
-  punycode_uint delta, punycode_uint numpoints, int firsttime ) _GL_ATTRIBUTE_CONST;
+static punycode_uint
+adapt (punycode_uint delta, punycode_uint numpoints, int firsttime)
+  _GL_ATTRIBUTE_CONST;
 
-static punycode_uint adapt(
-  punycode_uint delta, punycode_uint numpoints, int firsttime )
+     static punycode_uint adapt (punycode_uint delta, punycode_uint numpoints,
+				 int firsttime)
 {
   punycode_uint k;
 
@@ -123,20 +127,20 @@ static punycode_uint adapt(
   /* delta >> 1 is a faster way of doing delta / 2 */
   delta += delta / numpoints;
 
-  for (k = 0;  delta > ((base - tmin) * tmax) / 2;  k += base) {
-    delta /= base - tmin;
-  }
+  for (k = 0; delta > ((base - tmin) * tmax) / 2; k += base)
+    {
+      delta /= base - tmin;
+    }
 
   return k + (base - tmin + 1) * delta / (delta + skew);
 }
 
 /*** Main decode function ***/
 
-int punycode_decode(
-  size_t input_length,
-  const char input[],
-  size_t *output_length,
-  punycode_uint output[])
+int
+punycode_decode (size_t input_length,
+		 const char input[],
+		 size_t *output_length, punycode_uint output[])
 {
   punycode_uint n, out = 0, i, max_out, bias, oldi, w, k, digit, t;
   size_t b = 0, j, in;
@@ -145,29 +149,36 @@ int punycode_decode(
     return punycode_bad_input;
 
   /* Check that all chars are basic */
-  for (j = 0;  j < input_length;  ++j) {
-    if (!basic(input[j])) return punycode_bad_input;
-    if (input[j] == delimiter) b = j;
-  }
+  for (j = 0; j < input_length; ++j)
+    {
+      if (!basic (input[j]))
+	return punycode_bad_input;
+      if (input[j] == delimiter)
+	b = j;
+    }
 
-  max_out = *output_length > maxint ? maxint : (punycode_uint) *output_length;
+  max_out =
+    *output_length > maxint ? maxint : (punycode_uint) * output_length;
 
-  if (input[b] == delimiter) {
-    /* do not accept leading or trailing delimiter
-     *   - leading delim must be omitted if there is no ASCII char in u-label
-     *   - trailing delim means there where no non-ASCII chars in u-label
-     */
-    if (!b || b == input_length - 1) return punycode_bad_input;
+  if (input[b] == delimiter)
+    {
+      /* do not accept leading or trailing delimiter
+       *   - leading delim must be omitted if there is no ASCII char in u-label
+       *   - trailing delim means there where no non-ASCII chars in u-label
+       */
+      if (!b || b == input_length - 1)
+	return punycode_bad_input;
 
-    if (b >= max_out) return punycode_big_output;
+      if (b >= max_out)
+	return punycode_big_output;
 
-    /* Check that all chars before last delimiter are basic chars */
-    /* and copy the first b code points to the output. */
-    for (j = 0; j < b; j++)
-      output[out++] = input[j];
+      /* Check that all chars before last delimiter are basic chars */
+      /* and copy the first b code points to the output. */
+      for (j = 0; j < b; j++)
+	output[out++] = input[j];
 
-    b += 1; /* advance to non-basic char encoding */
-  }
+      b += 1;			/* advance to non-basic char encoding */
+    }
 
   /* Initialize the state: */
   n = initial_n;
@@ -176,47 +187,57 @@ int punycode_decode(
 
   /* Main decoding loop:  Start just after the last delimiter if any  */
   /* basic code points were copied; start at the beginning otherwise. */
-  for (in = b;  in < input_length;  ++out) {
+  for (in = b; in < input_length; ++out)
+    {
 
-    /* in is the index of the next ASCII code point to be consumed, */
-    /* and out is the number of code points in the output array.    */
+      /* in is the index of the next ASCII code point to be consumed, */
+      /* and out is the number of code points in the output array.    */
 
-    /* Decode a generalized variable-length integer into delta,  */
-    /* which gets added to i.  The overflow checking is easier   */
-    /* if we increase i as we go, then subtract off its starting */
-    /* value at the end to obtain delta.                         */
-    for (oldi = i, w = 1, k = base;  ;  k += base) {
-      if (in >= input_length) return punycode_bad_input;
-      digit = decode_digit(input[in++]);
-      if (digit >= base) return punycode_bad_input;
-      if (digit > (maxint - i) / w) return punycode_overflow;
-      i += digit * w;
-      t = k <= bias /* + tmin */ ? tmin :     /* +tmin not needed */
-          k >= bias + tmax ? tmax : k - bias;
-      if (digit < t) break;
-      if (w > maxint / (base - t)) return punycode_overflow;
-      w *= (base - t);
+      /* Decode a generalized variable-length integer into delta,  */
+      /* which gets added to i.  The overflow checking is easier   */
+      /* if we increase i as we go, then subtract off its starting */
+      /* value at the end to obtain delta.                         */
+      for (oldi = i, w = 1, k = base;; k += base)
+	{
+	  if (in >= input_length)
+	    return punycode_bad_input;
+	  digit = decode_digit (input[in++]);
+	  if (digit >= base)
+	    return punycode_bad_input;
+	  if (digit > (maxint - i) / w)
+	    return punycode_overflow;
+	  i += digit * w;
+	  t = k <= bias /* + tmin */ ? tmin :	/* +tmin not needed */
+	    k >= bias + tmax ? tmax : k - bias;
+	  if (digit < t)
+	    break;
+	  if (w > maxint / (base - t))
+	    return punycode_overflow;
+	  w *= (base - t);
+	}
+
+      bias = adapt (i - oldi, out + 1, oldi == 0);
+
+      /* i was supposed to wrap around from out+1 to 0,   */
+      /* incrementing n each time, so we'll fix that now: */
+      if (i / (out + 1) > maxint - n)
+	return punycode_overflow;
+      n += i / (out + 1);
+      if (n > 0x10FFFF || (n >= 0xD800 && n <= 0xDBFF))
+	return punycode_bad_input;
+      i %= (out + 1);
+
+      /* Insert n at position i of the output: */
+
+      /* not needed for Punycode: */
+      /* if (basic(n)) return punycode_bad_input; */
+      if (out >= max_out)
+	return punycode_big_output;
+
+      memmove (output + i + 1, output + i, (out - i) * sizeof *output);
+      output[i++] = n;
     }
 
-    bias = adapt(i - oldi, out + 1, oldi == 0);
-
-    /* i was supposed to wrap around from out+1 to 0,   */
-    /* incrementing n each time, so we'll fix that now: */
-    if (i / (out + 1) > maxint - n) return punycode_overflow;
-    n += i / (out + 1);
-    if (n > 0x10FFFF || (n >= 0xD800 && n <= 0xDBFF)) return punycode_bad_input;
-    i %= (out + 1);
-
-    /* Insert n at position i of the output: */
-
-    /* not needed for Punycode: */
-    /* if (basic(n)) return punycode_bad_input; */
-    if (out >= max_out) return punycode_big_output;
-
-    memmove(output + i + 1, output + i, (out - i) * sizeof *output);
-    output[i++] = n;
-  }
-
   *output_length = (size_t) out;
   /* cannot overflow because out <= old value of *output_length */
   return punycode_success;
@@ -226,7 +247,7 @@ int punycode_decode(
    the target symbol hidden, hence the alias.  */
 #ifdef HAVE_SYMVER_ALIAS_SUPPORT
 __typeof__ (_idn2_punycode_decode_internal) _idn2_punycode_decode
-   __attribute__ ((visibility ("default"),
-                   alias ("_idn2_punycode_decode_internal")));
+  __attribute__((visibility ("default"),
+		 alias ("_idn2_punycode_decode_internal")));
 __asm__ (".symver _idn2_punycode_decode, _idn2_punycode_decode@IDN2_0.0.0");
 #endif
