@@ -35,12 +35,11 @@
 extern int
 _idn2_punycode_encode_internal (size_t input_length,
 				const uint32_t input[],
-				size_t * output_length, char output[]);
+				size_t *output_length, char output[]);
 
 extern int
 _idn2_punycode_decode_internal (size_t input_length,
 				const char input[],
-				size_t * output_length,
-				uint32_t output[]);
+				size_t *output_length, uint32_t output[]);
 
 #endif /* LIBIDN2_PUNYCODE_H */
